package VMOMI::HostUnresolvedVmfsResolutionSpecVmfsUuidResolution;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
